netapp_ontap.models.iscsi_connection API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.iscsi_connection`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IscsiConnectionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IscsiConnection object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `authentication_type: str GET`

    The iSCSI authentication type used to establish the connection.

    Valid choices:

    - chap
    - none
  `cid: Size GET`

    The identifier of the connection within the session.

  `initiator_address: IscsiConnectionInitiatorAddress GET`

    The TCP socket information for the initiator end of the connection. This is useful for network packet debugging.

  `interface: IscsiConnectionInterface GET`

    The network interface information for the target end of the connection.

  `links: CollectionLinks GET`

    The links field of the iscsi_connection.